
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.22.2',
    'branch_nick': 'patch-0-Release__1_22_2_preparation',
    'revision_id': '1640edd8514f74d444775b5d80ec864764edef0a',
    'revno': 9385
}
